==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","");
define("_REALNAME","ͨԧ");
define("_FUNCTIONS","èѴ");
define("_PREVIOUS","˹ҡ͹");
define("_MEMBERSLIST","Member Lists");
define("_GREETINGS","Թյ͹Ѻس");
define("_SORTBY","Ѵ§:");
define("_MNICKNAME","¡");
define("_MREALNAME","ͨԧ");
define("_MEMAIL","");
define("_MURL","url");
define("_ONLINEREG","Ҫԡ online й:");
define("_WEHAVE","Ҫԡ");
define("_MREGISTERED"," ШӹǹҪԡ online ");
define("_MREGONLINE","");
define("_REGSOFAR","Ҫԡ");
define("_USERSFOUND","Ҫԡ");
define("_USERSSHOWN","ռ");
define("_NOMEMBERS","辺Ҫԡ");
define("_PAGES","˹");
define("_HOMEPAGE","HomePage");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Members_List/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_EMAIL","");
define("_REALNAME","ͨԧ");
define("_FUNCTIONS","èѴ");
define("_PREVIOUS","˹ҡ͹");
define("_MEMBERSLIST","Member Lists");
define("_GREETINGS","Թյ͹Ѻس");
define("_SORTBY","Ѵ§:");
define("_MNICKNAME","¡");
define("_MREALNAME","ͨԧ");
define("_MEMAIL","");
define("_MURL","url");
define("_ONLINEREG","Ҫԡ online й:");
define("_WEHAVE","Ҫԡ");
define("_MREGISTERED"," ШӹǹҪԡ online ");
define("_MREGONLINE","");
define("_REGSOFAR","Ҫԡ");
define("_USERSFOUND","Ҫԡ");
define("_USERSSHOWN","ռ");
define("_NOMEMBERS","辺Ҫԡ");
define("_PAGES","˹");
define("_HOMEPAGE","HomePage");

?>
